Class: Valkyrie::Persistence::Fedora::Persister::ModelConverter::IntegerValue
- Inherits:
-
MappedFedoraValue
- Object
- ValueMapper
- MappedFedoraValue
- Valkyrie::Persistence::Fedora::Persister::ModelConverter::IntegerValue
- Defined in:
- lib/valkyrie/persistence/fedora/persister/model_converter.rb
Overview
Class for mapping Property objects for Integer values
Instance Attribute Summary
Attributes inherited from ValueMapper
Class Method Summary collapse
-
.handles?(value) ⇒ Boolean
Determines whether or not the value is a Property for Integer values.
Instance Method Summary collapse
-
#result ⇒ Valkyrie::Persistence::Fedora::Persister::ModelConverter::Property
Generates the Property for this Integer #<RDF::Literal::Integer:0x3fc8a104f570("1"^^http://example.com/predicate/valkyrie_int)>.
Methods inherited from ValueMapper
Constructor Details
This class inherits a constructor from Valkyrie::ValueMapper
Class Method Details
.handles?(value) ⇒ Boolean
Determines whether or not the value is a Property for Integer values
425 426 427 |
# File 'lib/valkyrie/persistence/fedora/persister/model_converter.rb', line 425 def self.handles?(value) value.is_a?(Property) && value.value.is_a?(Integer) end |
Instance Method Details
#result ⇒ Valkyrie::Persistence::Fedora::Persister::ModelConverter::Property
Generates the Property for this Integer #<RDF::Literal::Integer:0x3fc8a104f570("1"^^http://example.com/predicate/valkyrie_int)>
432 433 434 435 436 437 |
# File 'lib/valkyrie/persistence/fedora/persister/model_converter.rb', line 432 def result map_value(converted_value: RDF::Literal.new( value.value, datatype: PermissiveSchema.valkyrie_int )) end |